package com.antai.sport.http.server.server.api.business.teamtraining.controller;

import com.antai.sport.http.server.common.base.Result;
import com.antai.sport.http.server.server.api.business.simplematch.dto.ReqSimpleMatchRegist;
import com.antai.sport.http.server.server.api.business.teamtraining.dto.TeamTrainingBannerResponseDTO;
import com.antai.sport.http.server.server.api.business.teamtraining.dto.TeamTrainingForListResponseDTO;
import com.antai.sport.http.server.server.api.business.teamtraining.dto.TeamTrainingRegistRequestDTO;
import com.antai.sport.http.server.server.api.business.teamtraining.service.TeamTrainingService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

import static com.antai.sport.http.server.common.util.ResultUtil.success;

@RequestMapping("/team/training")
@RestController
@Api(tags = {"团练接口"})
public class TeamTrainingController {
    @Resource
    private TeamTrainingService teamTrainingService;

    @ApiOperation("获取banner地址")
    @GetMapping("/banner/list")
    public ResponseEntity<Result<List<TeamTrainingBannerResponseDTO>>> getSimpleMatchBannerList() {
        return success(teamTrainingService.getTeamTrainingBannerList());
    }

    @ApiOperation("查询所有未完团练列表")
    @GetMapping("/list")
    public ResponseEntity<Result<List<TeamTrainingForListResponseDTO>>> getUnFinishedTeamTrainingForServer() {
        return success(teamTrainingService.getUnFinishedTeamTrainingForServer());
    }

    @ApiOperation("通过用户id查询未完团练列表")
    @GetMapping("/list/user/{userId}")
    public ResponseEntity<Result<List<TeamTrainingForListResponseDTO>>> getUnFinishedTeamTrainingForUser(@PathVariable("userId") Long userId) {
        return success(teamTrainingService.getUnFinishedTeamTrainingForUser(userId));
    }

    @ApiOperation("团练报名报名")
    @PostMapping("/regist")
    public ResponseEntity<Result> register(@RequestBody TeamTrainingRegistRequestDTO param) {
        teamTrainingService.regist(param);
        return success();
    }
}
